summaryrefslogtreecommitdiffstats
path: root/src/widgets/qmenubar.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/widgets/qmenubar.cpp')
-rw-r--r--src/widgets/qmenubar.cpp30
1 files changed, 15 insertions, 15 deletions
diff --git a/src/widgets/qmenubar.cpp b/src/widgets/qmenubar.cpp
index ebe231853..96a111b49 100644
--- a/src/widgets/qmenubar.cpp
+++ b/src/widgets/qmenubar.cpp
@@ -38,25 +38,25 @@
**
**********************************************************************/
// qmainwindow.h before qmenubar.h because of GCC-2.7.* compatibility
// ### could be reorganised by discarding INCLUDE_MENUITEM_DEF and put
// the relevant declarations in a private header?
-#include "qmainwindow.h"
+#include "ntqmainwindow.h"
#ifndef QT_NO_MENUBAR
-#include "qmenubar.h"
-#include "qpopupmenu.h"
-#include "qaccel.h"
-#include "qpainter.h"
-#include "qdrawutil.h"
-#include "qapplication.h"
-#include "qguardedptr.h"
-#include "qlayout.h"
-#include "qcleanuphandler.h"
+#include "ntqmenubar.h"
+#include "ntqpopupmenu.h"
+#include "ntqaccel.h"
+#include "ntqpainter.h"
+#include "ntqdrawutil.h"
+#include "ntqapplication.h"
+#include "ntqguardedptr.h"
+#include "ntqlayout.h"
+#include "ntqcleanuphandler.h"
#include "../kernel/qinternal_p.h"
-#include "qstyle.h"
-#include "qtimer.h"
+#include "ntqstyle.h"
+#include "ntqtimer.h"
#if defined(QT_ACCESSIBILITY_SUPPORT)
-#include "qaccessible.h"
+#include "ntqaccessible.h"
#endif
class TQMenuDataData {
@@ -76,7 +76,7 @@ extern int qt_xfocusout_grab_counter; // defined in qapplication_x11.cpp
#endif
/*!
- \class TQMenuBar qmenubar.h
+ \class TQMenuBar ntqmenubar.h
\brief The TQMenuBar class provides a horizontal menu bar.
\ingroup application
@@ -38,25 +38,25 @@
**
**********************************************************************/
-// qmainwindow.h before qmenubar.h because of GCC-2.7.* compatibility
+// ntqmainwindow.h before ntqmenubar.h because of GCC-2.7.* compatibility
// ### could be reorganised by discarding INCLUDE_MENUITEM_DEF and put
// the relevant declarations in a private header?